@@ -1,11 +1,11 @@
 import dataclasses  # type: ignore
-from pydantic.dataclasses import dataclass
 from dataclasses import InitVar
 from typing import Any, Dict, Optional
 import inspect
 import requests
 from requests.adapters import HTTPAdapter
-from requests.packages.urllib3.util.retry import Retry
+# from requests.packages.urllib3.util.retry import Retry
+from urllib3.util.retry import Retry
 from logging import getLogger
 
 from deeplabel.exceptions import InvalidAPIResponse
@@ -51,7 +51,7 @@ class BaseClient:
         response = self.session.post(
             url, json=json, headers=self.headers)
         if response.status_code > 200:
-            logger.error(f"{response.status_code}  {url} failed. {response.text}")
+            logger.error(f"{response.status_code}  {url} failed. {response.text} ; data:{json}")
             raise InvalidAPIResponse(f"{response.status_code}  {url} {response.text}")
         return response
 
@@ -145,5 +145,6 @@ class DeeplabelLoginClient(BaseClient, _MixinLogin):
         super().__post_init__()
         # Get user and token
         user: auth.users.User = auth.users.User.from_login(email, password, self)
+        assert user.root_secret_key, f"No root secret key found in user"
         token = auth.tokens.UserToken.from_root_secret_key(user.root_secret_key, self)
         self.token = token.hash
