@@ -9,6 +9,7 @@ from pydantic import validator
 import deeplabel.label.videos.frames
 import deeplabel.label.videos.detections
 import deeplabel.client
+from deeplabel.exceptions import InvalidIdError
 import yarl
 import os
 from deeplabel.exceptions import DeeplabelValueError
@@ -84,7 +85,7 @@ class Video(DeeplabelBase):
     project_id: str
     input_url: str
     video_urls: Optional[_VideoUrl]
-    video_url: Optional[str]
+    video_url: Optional[str] # videoUrls.source.url if exists else videoUrl is used for legacy support
     thumbnail_url: Optional[str]
     status: _LabelVideoStatus
     extraction_points: List[_ExtractionPoint]
@@ -93,7 +94,7 @@ class Video(DeeplabelBase):
     labelling_fps: int
 
     @validator('video_url', always=True)
-    def validate_url(cls, value, values):
+    def validate_url(cls, value, values): #type: ignore
         """
         Validate that either video_url or video_urls.source.url exists
         Since videoUrl can't be updated anymore, since it's deprecated,
@@ -103,7 +104,7 @@ class Video(DeeplabelBase):
         """
         # video_urls.source.url
         try:
-            source_url = values.get('video_urls',{}).source.url
+            source_url:str = values.get('video_urls',{}).source.url #type: ignore
         except:
             # should have either of the two
             # If video_url key is empty
@@ -121,11 +122,21 @@ class Video(DeeplabelBase):
         videos = resp.json()["data"]["videos"]
         videos = [cls(**video, client=client) for video in videos]
         return videos # type: ignore
+    
+    @classmethod
+    def from_video_id(cls, video_id:str, client:'deeplabel.client.BaseClient')->"Video":
+        videos = cls._from_search_params({"videoId": video_id}, client)
+        if not len(videos):
+            raise InvalidIdError(
+                f"Failed to fetch video with videoId  : {video_id}"
+            )
+        # since videoId should fetch only 1 video, return that video instead of a list
+        return videos[0]
 
     @property
     def ext(self):
         """Extenion of the video, deduced from path/name"""
-        return os.path.splitext(yarl.URL(self.video_urls.source.url).name)[-1]
+        return os.path.splitext(yarl.URL(self.video_url).name)[-1]
 
 
     @property
